@@ -13,16 +13,22 @@
 """Unit tests for the binary event stream decoder. """
 import pytest
 
-from tests import mock
-
-from botocore.parsers import EventStreamXMLParser
 from botocore.eventstream import (
-    EventStreamMessage, MessagePrelude, EventStreamBuffer,
-    ChecksumMismatch, InvalidPayloadLength, InvalidHeadersLength,
-    DuplicateHeader, EventStreamHeaderParser, DecodeUtils, EventStream,
-    NoInitialResponseError
+    ChecksumMismatch,
+    DecodeUtils,
+    DuplicateHeader,
+    EventStream,
+    EventStreamBuffer,
+    EventStreamHeaderParser,
+    EventStreamMessage,
+    InvalidHeadersLength,
+    InvalidPayloadLength,
+    MessagePrelude,
+    NoInitialResponseError,
 )
 from botocore.exceptions import EventStreamError
+from botocore.parsers import EventStreamXMLParser
+from tests import mock
 
 EMPTY_MESSAGE = (
     b'\x00\x00\x00\x10\x00\x00\x00\x00\x05\xc2H\xeb}\x98\xc8\xff',
