@@ -367,6 +367,28 @@ class TestURLLib3Session(unittest.TestCase):
             last_call = self.proxy_manager_fun.call_args[-1]
             self.assertIs(last_call['ssl_context'].check_hostname, True)
 
+    def test_proxy_ssl_context_does_not_use_check_hostname_if_ip_address(self):
+        cert = ('/some/cert', '/some/key')
+        proxies_config = {'proxy_client_cert': "path/to/cert"}
+        urls = ['https://1.2.3.4:5678',
+                'https://4.6.0.0',
+                'https://[FE80::8939:7684:D84b:a5A4%251]:1234',
+                'https://[FE80::8939:7684:D84b:a5A4%251]',
+                'https://[FE80::8939:7684:D84b:a5A4]:999',
+                'https://[FE80::8939:7684:D84b:a5A4]',
+                'https://[::1]:789']
+        for proxy_url in urls:
+            with mock.patch('botocore.httpsession.SSLContext'):
+                proxies = {'https': proxy_url}
+                session = URLLib3Session(
+                    proxies=proxies, client_cert=cert,
+                    proxies_config=proxies_config
+                )
+                self.request.url = 'https://example.com/'
+                session.send(self.request.prepare())
+                last_call = self.proxy_manager_fun.call_args[-1]
+                self.assertIs(last_call['ssl_context'].check_hostname, False)
+
     def test_basic_request(self):
         session = URLLib3Session()
         session.send(self.request.prepare())
